import axios from 'axios';

const BASE_URL = 'http://127.0.0.1:5000';
const BASE_URL_2='http://127.0.0.1:3001';
const BASE_URL_3='http://127.0.0.1:8080';
// 调用 Flask 进行图像识别
export const predict = async (data: any) => {
  try {
    const response = await axios.post(`${BASE_URL}/predict`, { data });
    return response.data;
  } catch (error) {
    console.error('图像预测时发生错误:', error);
    throw error;
  }
};
// 调用 Flask 进行RAG增强回答
export const queryRAGKnowledge = async (query: string) => {
  try {
    const response = await axios.post(`${BASE_URL_2}/query`, { query });
    // 提取结果中的 content 字段
    const contents = response.data.results.map((result: { sentence: any; }) => result.sentence);
    return contents; // 返回内容列表

  } catch (error) {
    console.error('查询 RAG 知识库时发生错误：', error);
    throw error;
  }
};
// 登录请求方法
export const login = async (formData: { username: string; password: string }) => {
  try {
    const response = await axios.post(`${BASE_URL_3}/api/login`, formData);
    // 检查后端返回的响应结果
    if (response.data.success) {
      console.log('登录成功');
      return response.data;
    } else {
      console.error('登录失败：', response.data.message);
      throw new Error(response.data.message || '登录失败，请检查账号和密码！');
    }
  } catch (error) {
    console.error('登录请求时发生错误：', error);
    throw error;
  }
};